Graphical User Interface
------------------------

The GUI module provides graphical interface components for HBAT.

Main Window
-----------

.. automodule:: hbat.gui.main_window
   :members:
   :undoc-members:
   :show-inheritance:

Parameter Panel
---------------

.. automodule:: hbat.gui.parameter_panel
   :members:
   :undoc-members:
   :show-inheritance:

Results Panel
-------------

.. automodule:: hbat.gui.results_panel
   :members:
   :undoc-members:
   :show-inheritance:

Chain Visualization
-------------------

.. automodule:: hbat.gui.chain_visualization
   :members:
   :undoc-members:
   :show-inheritance: